==> xmake_2.8.7+ds.orig.tar.xz: xmake-2.8.7/NOTICE.md <==
A cross-platform build utility based on Lua
Copyright 2015-present The TBOOX Open Source Group

This product includes software developed by The TBOOX Open Source Group (https://tboox.org/).

-------------------------------------------------------------------------------

This product depends on 'lua-cjson', The Lua CJSON module provides JSON support for Lua,
which can be obtained at:

  * LICENSE:
    * core/src/lua-cjson/lua-cjson/LICENSE (MIT License)
  * HOMEPAGE:
    * https://www.kyne.com.au/~mark/software/lua-cjson.php

This product depends on 'pdcurses', an implementation of X/Open curses for multiple platforms,
which can be obtained at:

  * LICENSE:
    * Public Domain License
  * HOMEPAGE:
    * http://pdcurses.org/

This product depends on 'libsv', Public domain semantic versioning in c,
which can be obtained at:

  * LICENSE:
    * core/src/sv/sv/UNLICENSE (Public Domain License)
  * HOMEPAGE:
    * https://github.com/uael/sv

This product depends on 'LuaJIT', a Just-In-Time Compiler for Lua,
which can be obtained at:

  * LICENSE:
    * core/src/luajit/luajit/COPYRIGHT (MIT License)
  * HOMEPAGE:
    * http://luajit.org/

This product depends on 'Lua', The Lua Programing Language,
which can be obtained at:

  * LICENSE:
    * https://www.lua.org/license.html (MIT License)
  * HOMEPAGE:
    * http://lua.org/

This product depends on 'lz4', Extremely Fast Compression algorithm,
which can be obtained at:

  * LICENSE:
    * https://github.com/lz4/lz4/blob/dev/LICENSE
  * HOMEPAGE:
    * https://www.lz4.org/

This product depends on 'xxHash', Extremely fast non-cryptographic hash algorithm,
which can be obtained at:

  * LICENSE:
    * https://github.com/Cyan4973/xxHash/blob/dev/LICENSE
  * HOMEPAGE:
    * https://www.xxhash.com/

This product depends on 'tbox', The Treasure Box Library,
which can be obtained at:

  * LICENSE:
    * core/src/tbox/tbox/LICENSE.md (Apache License 2.0)
  * HOMEPAGE:
    * https://tboox.org/

==> xmake_2.9.9+ds.orig.tar.xz: xmake-2.9.9/NOTICE.md <==
A cross-platform build utility based on Lua
Copyright 2015-present The TBOOX Open Source Group

This product includes software developed by The TBOOX Open Source Group (https://tboox.org/).

-------------------------------------------------------------------------------

This product depends on 'lua-cjson', The Lua CJSON module provides JSON support for Lua,
which can be obtained at:

  * LICENSE:
    * core/src/lua-cjson/lua-cjson/LICENSE (MIT License)
  * HOMEPAGE:
    * https://www.kyne.com.au/~mark/software/lua-cjson.php

This product depends on 'pdcurses', an implementation of X/Open curses for multiple platforms,
which can be obtained at:

  * LICENSE:
    * Public Domain License
  * HOMEPAGE:
    * http://pdcurses.org/

This product depends on 'libsv', Public domain semantic versioning in c,
which can be obtained at:

  * LICENSE:
    * core/src/sv/sv/UNLICENSE (Public Domain License)
  * HOMEPAGE:
    * https://github.com/uael/sv

This product depends on 'LuaJIT', a Just-In-Time Compiler for Lua,
which can be obtained at:

  * LICENSE:
    * core/src/luajit/luajit/COPYRIGHT (MIT License)
  * HOMEPAGE:
    * http://luajit.org/

This product depends on 'Lua', The Lua Programming Language,
which can be obtained at:

  * LICENSE:
    * https://www.lua.org/license.html (MIT License)
  * HOMEPAGE:
    * http://lua.org/

This product depends on 'lz4', Extremely Fast Compression algorithm,
which can be obtained at:

  * LICENSE:
    * https://github.com/lz4/lz4/blob/dev/LICENSE
  * HOMEPAGE:
    * https://www.lz4.org/

This product depends on 'xxHash', Extremely fast non-cryptographic hash algorithm,
which can be obtained at:

  * LICENSE:
    * https://github.com/Cyan4973/xxHash/blob/dev/LICENSE
  * HOMEPAGE:
    * https://www.xxhash.com/

This product depends on 'tbox', The Treasure Box Library,
which can be obtained at:

  * LICENSE:
    * core/src/tbox/tbox/LICENSE.md (Apache License 2.0)
  * HOMEPAGE:
    * https://tboox.org/
